@@ -147,8 +147,8 @@ namespace openshot
 		int cache_size;
 		bool is_writing;
 		bool is_open;
-		int64 write_video_count;
-		int64 write_audio_count;
+		int64_t write_video_count;
+		int64_t write_audio_count;
 
 		bool prepare_streams;
 		bool write_header;
@@ -241,13 +241,13 @@ namespace openshot
 		bool write_video_packet(std::shared_ptr<Frame> frame, AVFrame* frame_final);
 
 		/// write all queued frames
-		void write_queued_frames() throw (ErrorEncodingVideo);
+		void write_queued_frames();
 
 	public:
 
 		/// @brief Constructor for FFmpegWriter. Throws one of the following exceptions.
 		/// @param path The file path of the video file you want to open and read
-		FFmpegWriter(string path) throw(InvalidFile, InvalidFormat, InvalidCodec, InvalidOptions, OutOfMemory);
+		FFmpegWriter(string path);
 
 		/// Close the writer
 		void Close();
@@ -258,8 +258,11 @@ namespace openshot
 		/// Determine if writer is open or closed
 		bool IsOpen() { return is_open; };
 
+		/// Determine if codec name is valid
+		static bool IsValidCodec(string codec_name);
+
 		/// Open writer
-		void Open() throw(InvalidFile, InvalidFormat, InvalidCodec, InvalidOptions, OutOfMemory, InvalidChannels, InvalidSampleRate);
+		void Open();
 
 		/// Output the ffmpeg info about this format, streams, and codecs (i.e. dump format)
 		void OutputStreamInfo();
@@ -283,8 +286,7 @@ namespace openshot
 		/// @param channels The number of audio channels needed in this file
 		/// @param channel_layout The 'layout' of audio channels (i.e. mono, stereo, surround, etc...)
 		/// @param bit_rate The audio bit rate used during encoding
-		void SetAudioOptions(bool has_audio, string codec, int sample_rate, int channels, ChannelLayout channel_layout, int bit_rate)
-				throw(InvalidFile, InvalidFormat, InvalidCodec, InvalidOptions, OutOfMemory, InvalidChannels);
+		void SetAudioOptions(bool has_audio, string codec, int sample_rate, int channels, ChannelLayout channel_layout, int bit_rate);
 
 		/// @brief Set the cache size
 		/// @param new_size The number of frames to queue before writing to the file
@@ -300,15 +302,14 @@ namespace openshot
 		/// @param interlaced Does this video need to be interlaced?
 		/// @param top_field_first Which frame should be used as the top field?
 		/// @param bit_rate The video bit rate used during encoding
-		void SetVideoOptions(bool has_video, string codec, Fraction fps, int width, int height,Fraction pixel_ratio, bool interlaced, bool top_field_first, int bit_rate)
-				throw(InvalidFile, InvalidFormat, InvalidCodec, InvalidOptions, OutOfMemory, InvalidChannels);
+		void SetVideoOptions(bool has_video, string codec, Fraction fps, int width, int height,Fraction pixel_ratio, bool interlaced, bool top_field_first, int bit_rate);
 
 		/// @brief Set custom options (some codecs accept additional params). This must be called after the
 		/// PrepareStreams() method, otherwise the streams have not been initialized yet.
 		/// @param stream The stream (openshot::StreamType) this option should apply to
 		/// @param name The name of the option you want to set (i.e. qmin, qmax, etc...)
 		/// @param value The new value of this option
-		void SetOption(StreamType stream, string name, string value) throw(NoStreamsFound, InvalidOptions);
+		void SetOption(StreamType stream, string name, string value);
 
 		/// @brief Write the file header (after the options are set). This method is called automatically
 		/// by the Open() method if this method has not yet been called.
@@ -316,13 +317,13 @@ namespace openshot
 
 		/// @brief Add a frame to the stack waiting to be encoded.
 		/// @param frame The openshot::Frame object to write to this image
-		void WriteFrame(std::shared_ptr<Frame> frame) throw(ErrorEncodingVideo, WriterClosed);
+		void WriteFrame(std::shared_ptr<Frame> frame);
 
 		/// @brief Write a block of frames from a reader
 		/// @param reader A openshot::ReaderBase object which will provide frames to be written
 		/// @param start The starting frame number of the reader
 		/// @param length The number of frames to write
-		void WriteFrame(ReaderBase* reader, long int start, long int length) throw(ErrorEncodingVideo, WriterClosed);
+		void WriteFrame(ReaderBase* reader, int64_t start, int64_t length);
 
 		/// @brief Write the file trailer (after all frames are written). This is called automatically
 		/// by the Close() method if this method has not yet been called.
